@@ -587,10 +587,8 @@ class BaseProject:
                 plt.legend(loc=(1.,1.))
                 plt.show()
                 plt.savefig(points_dir+ f"/points_distribution_PCA.png")  
-                self.project_logger.add_figure('data distribution_PCA', fig)
+                self.project_logger.add_figure('data_distribution_PCA', fig)
 
-                
-    
         elif domain_type == "image":
 
             if len(self.dims) == 1 :
@@ -715,7 +713,7 @@ class BaseProject:
             if best_val:
                 performances.append(best_val)
         performances = np.array(performances)
-        if performances == np.array([]):
+        if len(performances) == 0:
             raise ValueError(f"No performances are saved.")
         return (performances, best_model_types, best_model_structures)
 
@@ -773,8 +771,7 @@ class BaseProject:
                 best_model_structures.update({best_metadata : best_model_structures[best_metadata]+1})
             
         performances = np.array(performances)
-
-        if performances == np.array([]):
+        if len(performances)==0:
             raise ValueError(f"None is in performances. You may have not saved {model_type}")
 
         return (performances, best_model_structures)
@@ -833,7 +830,7 @@ class BaseProject:
                 performances.append(best_val)
             
         performances = np.array(performances)
-        if performances == np.array([]):
+        if len(performances) == 0:
             raise ValueError(f"None is in performances. You may have inputted the wrong model strucutre.")
         return (performances, metadata)
                     
@@ -1040,7 +1037,8 @@ class Project(BaseProject):
             plt.ylim = (ymin, ymax)
             self._create_folder(self.project_path+"/results")
             plt.show()
-            plt.savefig(self.project_path+f"/results/{plt_title}.png")
+            file_name = plt_title.replace(" ", "-")
+            plt.savefig(self.project_path+f"/results/{file_name}.png")
             self.project_logger.add_figure(f"results/{plt_title}", fig1)
             
             plt.close(fig1)
@@ -1079,7 +1077,8 @@ class Project(BaseProject):
         plt.setp(autotexts, size=8, weight="bold")
         plt.axis('equal')
         plt.show()
-        plt.savefig(self.project_path+f"/results/{plt_title} the Best Model Structures.png")
+        file_name = plt_title.replace(" ", "-")
+        plt.savefig(self.project_path+f"/results/{file_name}-the-Best-Model-Structures.png")
         self.project_logger.add_figure(f"results/{plt_title} the Best Model Structures", fig2)
         plt.close(fig2)
         
@@ -1091,7 +1090,7 @@ class Project(BaseProject):
         plt.title(f'{plt_title} the Best Model Types')
         plt.legend(wedges, best_model_types.keys(), title="Model Types", loc="center left",bbox_to_anchor=(1, 0, 0.5, 1))
         plt.show()
-        plt.savefig(self.project_path+f"/results/{plt_title} the Best Model Types.png")
+        plt.savefig(self.project_path+f"/results/{file_name}-the-Best-Model-Types.png")
         self.project_logger.add_figure(f"results/{plt_title} the Best Model Types", fig3)
         plt.close(fig3)
 
@@ -1123,6 +1122,8 @@ class Project(BaseProject):
 
             tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``, dictionary containing information of the search)
         """
+        if self.n_classes is None and val_metric != "val/loss": # regression
+            raise AssertionError(f"{val_metric} is not a valid metric for regression tasks.")
         performances, best_model_structures = self.search_with_model_type(val_metric=val_metric, model_type=model_type)
         random_state_dir_list = self.get_available_random_states()
         ymin = performances.min() - 0.1 if performances.min() > 0.1 else 0
@@ -1145,7 +1146,8 @@ class Project(BaseProject):
             plt_title = f'Best Performances : Model Type \n{model_type.__name__}'
         plt.title(plt_title)
         plt.show()
-        plt.savefig(self.project_path+f"/results/{plt_title}.png")
+        file_name = f'Best-Performances-{model_type.__name__}'
+        plt.savefig(self.project_path+f"/results/{file_name}.png")
         self.project_logger.add_figure(f"results/{plt_title}", fig1)
         plt.close(fig1)
         self.update_project_metadata()
@@ -1185,6 +1187,8 @@ class Project(BaseProject):
             :alt: Plot example
             
         """
+        if self.n_classes is None and val_metric != "val/loss": # regression
+            raise AssertionError(f"{val_metric} is not a valid metric for regression tasks.")
         performances, metadata = self.search_with_model_type_hparams(
             val_metric=val_metric, model_type=model_type, **hparams
             )
@@ -1266,6 +1270,8 @@ class Project(BaseProject):
             :alt: Performance plot (box plot) of all models
 
         """
+        if self.n_classes is None and val_metric != "val/loss": # regression
+            raise AssertionError(f"{val_metric} is not a valid metric for regression tasks.")
         metadata_list, performances_list = self.search_all_models(val_metric)
         random_state_dir_list = self.get_available_random_states()
         random_number_list = []
@@ -1296,7 +1302,8 @@ class Project(BaseProject):
         plt.ylim = (ymin, ymax)
         plt.legend(title="Model Structures", loc="center left",bbox_to_anchor=(1, 0, 0.5, 1))
         plt.show()
-        plt.savefig(self.project_path+f"/results/{plt_title}.png")
+        file_name = plt_title.replace(" ", "-")
+        plt.savefig(self.project_path+f"/results/{file_name}.png")
         self.project_logger.add_figure(f'results/{plt_title}', fig1)
         
         plt.close(fig1)
@@ -1328,7 +1335,7 @@ class Project(BaseProject):
         plt.ylabel(val_metric)
         plt.grid(True)
         plt.show()
-        plt.savefig(self.project_path+f"/results/{plt_title}_boxplot.png")
+        plt.savefig(self.project_path+f"/results/{file_name}_boxplot.png")
         self.project_logger.add_figure(f'results/{plt_title}_boxplot', fig2)
 
         return (performances_list, metadata_list)
